@@ -235,3 +235,21 @@ def compute_plane_position_slide_per_frame(
             range(1, tiles_per_row + 1),  # row direction, left to right
         )
     ]
+
+
+def is_tiled_image(dataset: Dataset) -> bool:
+    """Determine whether a dataset represents a tiled image.
+
+    Returns
+    -------
+    bool:
+        True if the dataset is a tiled image. False otherwise.
+
+    """
+    if (
+        hasattr(dataset, 'TotalPixelMatrixRows') and
+        hasattr(dataset, 'TotalPixelMatrixColumns') and
+        hasattr(dataset, 'NumberOfFrames')
+    ):
+        return True
+    return False
